.. Advanced Usage master index

Advanced Usage
==============

Various advanced topics regarding cookiecutter usage.

.. toctree::
   :maxdepth: 2

   hooks
   user_config
   calling_from_python
   injecting_context
   suppressing_prompts
   templates_in_context
   copy_without_render
   replay
   cli_options
   choice_variables
   dict_variables
   template_extensions
   directories
